==> isddc-1.11.1-py3-none-any.whl: isddc/isddc_crypto.py <==
import hashlib


class IsddcCrypto:
    _split = '.'
    _flag = 65535

    def __init__(self, offset: int = -1):
        """
        offset: encrypt and decrypt need to be consistent,
        and cannot be an integer multiple of 0 or `len(data)`.
        """
        self.offset = offset

    def encrypt(self, data: str) -> str:
        lst = [ord(i) for i in data]
        len(lst) == 1 and lst.append(self._flag)
        for i in range(len(lst)):
            lst[i] += self._(lst, i)
        return self._split.join(str(i) for i in lst)

    def decrypt(self, data: str) -> str:
        lst = [int(i) for i in data.split(self._split)]
        for i in range(len(lst) - 1, -1, -1):
            lst[i] -= self._(lst, i)
        lst[-1] == self._flag and lst.remove(lst[-1])
        return ''.join(chr(i) for i in lst)

    def _(self, data: list, i: int):
        """索引加偏移量余长度取值"""
        return data[(i + self.offset) % len(data)]


class MD5:

    def __init__(self, *a, **kw):
        self.md5 = hashlib.md5(*a, **kw)

    def __new__(cls, data: str = None, *a, **kw):
        """Return the encrypted string directly"""
        if data is None:
            return object.__new__(cls)

        md5 = MD5(*a, **kw)
        md5.update(data)
        return md5.hexdigest

    def update(self, data):
        if isinstance(data, str):
            data = data.encode('UTF-8')

        if not isinstance(data, (str, bytes)):
            data = str(data).encode('UTF-8')

        self.md5.update(data)

    def update_str(self, data: str):
        self.md5.update(data.encode('UTF-8'))

    @property
    def hexdigest(self) -> str:
        return self.md5.hexdigest()


def encrypt(data: str, *, offset: int = -1) -> str:
    return IsddcCrypto(offset).encrypt(data)


def decrypt(data: str, *, offset: int = -1) -> str:
    return IsddcCrypto(offset).decrypt(data)

==> isddc-3.1.0-py3-none-any.whl: isddc/isddc_crypto.py <==
import hashlib


class IsddcCrypto:
    _split = '.'
    _flag = 65535

    def __init__(self, offset: int = -1):
        self.offset = offset

    def encrypt(self, cleartext: str) -> str:
        lst = [ord(i) for i in cleartext]
        len(lst) == 1 and lst.append(self._flag)
        for i in range(len(lst)):
            lst[i] += self._(lst, i)
        return self._split.join(str(i) for i in lst)

    def decrypt(self, ciphertext: str) -> str:
        lst = [int(i) for i in ciphertext.split(self._split)]
        for i in range(len(lst) - 1, -1, -1):
            lst[i] -= self._(lst, i)
        lst[-1] == self._flag and lst.remove(lst[-1])
        return ''.join(chr(i) for i in lst)

    def _(self, data: list, i: int):
        """索引加偏移量余长度取值"""
        return data[(i + self.offset) % len(data)]


class MD5:

    def __init__(self):
        self.md5 = hashlib.md5()

    def __new__(cls, data=None):
        """Return the encrypted string directly"""
        if data is None:
            return object.__new__(cls)

        md5 = MD5()
        md5.update(data)
        return md5.hexdigest

    def update(self, data):
        if isinstance(data, str):
            data = data.encode('UTF-8')

        if not isinstance(data, (str, bytes)):
            data = str(data).encode('UTF-8')

        self.md5.update(data)

    def update_str(self, data: str):
        self.md5.update(data.encode('UTF-8'))

    @property
    def hexdigest(self) -> str:
        return self.md5.hexdigest()


def encrypt(cleartext: str, *, offset: int = -1) -> str:
    return IsddcCrypto(offset).encrypt(cleartext)


def decrypt(ciphertext: str, *, offset: int = -1) -> str:
    return IsddcCrypto(offset).decrypt(ciphertext)
